@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -473,13 +473,5 @@
                                 zlib_crc32_x_compress, 0, 0, 0, 0, 0, 0, 0 },
 #endif
 
-#if defined(__LZO_PROFESSIONAL__)
-#  include "lzopro/t_db.ch"
-#endif
-
-
-
-/*
-vi:ts=4:et
-*/
 
+/* vim:set ts=4 sw=4 et: */
