@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -40,14 +40,12 @@
 #endif
 
 #include "lzo_conf.h"
-#include "lzo/lzo1z.h"
+#include <lzo/lzo1z.h>
 
 #define M2_MAX_OFFSET   0x0700
 #include "config1x.h"
 
 #endif /* already included */
 
-/*
-vi:ts=4:et
-*/
 
+/* vim:set ts=4 sw=4 et: */
