@@ -2,21 +2,13 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License,
-   version 2, as published by the Free Software Foundation.
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of
+   the License, or (at your option) any later version.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,12 +33,12 @@
 //
 ************************************************************************/
 
-#define N          0xffffL          /* size of ring buffer */
-#define THRESHOLD       2           /* lower limit for match length */
-#define F            2048           /* upper limit for match length */
+#define SWD_N          0xffffL          /* size of ring buffer */
+#define SWD_THRESHOLD       2           /* lower limit for match length */
+#define SWD_F            2048           /* upper limit for match length */
 
 
-#define LZO1B
+#define LZO1B 1
 #define LZO_COMPRESS_T  lzo1b_999_t
 #define lzo_swd_t       lzo1b_999_swd_t
 #include "lzo_mchw.ch"
@@ -236,7 +228,7 @@ lzo1b_999_compress_callback ( const lzo_bytep in , lzo_uint  in_len,
             assert(m_len > 0);
 
             r = find_match(c,swd,1,0);
-            assert(r == 0);
+            assert(r == 0); LZO_UNUSED(r);
             assert(c->look > 0);
 
             if (m_len <= M2_MAX_LEN && m_off <= M2_MAX_OFFSET &&
@@ -271,7 +263,7 @@ lzo1b_999_compress_callback ( const lzo_bytep in , lzo_uint  in_len,
             /* a literal */
             lit++;
             r = find_match(c,swd,1,0);
-            assert(r == 0);
+            assert(r == 0); LZO_UNUSED(r);
         }
         else
         {
@@ -306,7 +298,7 @@ lzo1b_999_compress_callback ( const lzo_bytep in , lzo_uint  in_len,
             /* 2 - code match */
             op = code_match(c,op,m_len,m_off);
             r = find_match(c,swd,m_len,1+ahead);
-            assert(r == 0);
+            assert(r == 0); LZO_UNUSED(r);
         }
 
         c->codesize = pd(op, out);
@@ -355,7 +347,4 @@ lzo1b_999_compress  ( const lzo_bytep in , lzo_uint  in_len,
 }
 
 
-/*
-vi:ts=4:et
-*/
-
+/* vim:set ts=4 sw=4 et: */
