@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -34,10 +34,11 @@
 // compression internal entry point.
 ************************************************************************/
 
-int _lzo1b_do_compress   ( const lzo_bytep in,  lzo_uint  in_len,
-                                 lzo_bytep out, lzo_uintp out_len,
-                                 lzo_voidp wrkmem,
-                                 lzo_compress_t func )
+LZO_LOCAL_IMPL(int)
+_lzo1b_do_compress   ( const lzo_bytep in,  lzo_uint  in_len,
+                             lzo_bytep out, lzo_uintp out_len,
+                             lzo_voidp wrkmem,
+                             lzo_compress_t func )
 {
     int r;
 #if defined(LZO_TEST_COMPRESS_OVERRUN)
@@ -149,7 +150,4 @@ void _lzo1b_stats_calc(lzo_stats_t *lzo_stats)
 #endif
 
 
-/*
-vi:ts=4:et
-*/
-
+/* vim:set ts=4 sw=4 et: */
